@@ -5,6 +5,7 @@ use super::*;
 const CAPACITY: usize = 128;
 
 /// Sized pool object with a max capacity of 128 items.
+#[derive(Copy, Clone)]
 pub struct SizedPool128<ItemType> { 
     items: [Option<ItemType>; CAPACITY], 
     order: [usize; CAPACITY], 
@@ -78,6 +79,14 @@ where ItemType: Copy + PartialEq
     }
 }
 
+impl<ItemType> Default for SizedPool128<ItemType>
+where ItemType: Copy + PartialEq
+{
+    fn default() -> Self {
+        SizedPool128::<ItemType>::new()
+    }
+}
+
 impl<ItemType> StackPool<ItemType> for SizedPool128<ItemType> {
     fn count(&self) -> &usize { 
         &self.count 
